@@ -5,7 +5,7 @@ local wanxiang = {}
 
 -- x-release-please-start-version
 
-wanxiang.version = "v13.3.4"
+wanxiang.version = "v13.7.0"
 
 -- x-release-please-end
 
@@ -119,6 +119,26 @@ function wanxiang.file_exists(filename)
     end
 end
 
+-- 判断字符是否为汉字
+function wanxiang.IsChineseCharacter(text)
+    local codepoint = utf8.codepoint(text)
+    return
+        (codepoint >= 0x4E00 and codepoint <= 0x9FFF)   -- Basic
+        or (codepoint >= 0x3400 and codepoint <= 0x4DBF)  -- Ext A
+        or (codepoint >= 0x20000 and codepoint <= 0x2A6DF) -- Ext B
+        or (codepoint >= 0x2A700 and codepoint <= 0x2B73F) -- Ext C
+        or (codepoint >= 0x2B740 and codepoint <= 0x2B81F) -- Ext D
+        or (codepoint >= 0x2B820 and codepoint <= 0x2CEAF) -- Ext E
+        or (codepoint >= 0x2CEB0 and codepoint <= 0x2EBEF) -- Ext F
+        or (codepoint >= 0x30000 and codepoint <= 0x3134F) -- Ext G
+        or (codepoint >= 0x31350 and codepoint <= 0x323AF) -- Ext H
+        or (codepoint >= 0x2EBF0 and codepoint <= 0x2EE5F) -- Ext I
+        or (codepoint >= 0xF900  and codepoint <= 0xFAFF)  -- Compatibility
+        or (codepoint >= 0x2F800 and codepoint <= 0x2FA1F) -- Compatibility Supplement
+        or (codepoint >= 0x2E80  and codepoint <= 0x2EFF)  -- Radicals Supplement
+        or (codepoint >= 0x2F00  and codepoint <= 0x2FDF)  -- Kangxi Radicals
+end
+
 ---按照优先顺序获取文件：用户目录 > 系统目录
 ---@param filename string 相对路径
 ---@retur string | nil
@@ -186,7 +206,6 @@ function wanxiang.get_user_id()
     installation_file:close()
     return user_id
 end
-
 wanxiang.INPUT_METHOD_MARKERS = {
     ["Ⅰ"] = "pinyin", --全拼
     ["Ⅱ"] = "zrm", --自然码双拼
@@ -197,9 +216,10 @@ wanxiang.INPUT_METHOD_MARKERS = {
     ["Ⅶ"] = "ziguang", --紫光双拼
     ["Ⅷ"] = "pyjj", --拼音加加
     ["Ⅸ"] = "gbpy", --国标双拼
-    ["Ⅹ"] = "lxsq", --乱序17
+    ["Ⅹ"] = "wxsp", --万象双拼
     ["Ⅺ"] = "zrlong", --自然龙
     ["Ⅻ"] = "hxlong", --汉心龙
+    ["Ⅼ"] = "lxsq", --乱序17
     ["ⅲ"] = "ⅲ", -- 间接辅助标记：命中则额外返回 md="ⅲ"
 }
 
